@@ -21,11 +21,14 @@ BEGIN {
         }
         XML::XPath::Literal->new($ns ? $ns->getExpanded : '');
     };
+
+    $XML::Atom::ForceUnicode = 0;
+    $XML::Atom::DefaultVersion = 0.3;
 }
 
 use base qw( XML::Atom::ErrorHandler Exporter );
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 package XML::Atom::Namespace;
 use strict;
